<?php

namespace Drupal\image_effects\Plugin\ImageToolkit\Operation\imagemagick;

use Drupal\imagemagick\Plugin\ImageToolkit\Operation\imagemagick\ImagemagickImageToolkitOperationBase;
use Drupal\image_effects\Plugin\ImageToolkit\Operation\BackgroundTrait;

/**
 * Defines ImageMagick Background operation.
 *
 * @ImageToolkitOperation(
 *   id = "image_effects_imagemagick_background",
 *   toolkit = "imagemagick",
 *   operation = "background",
 *   label = @Translation("Background"),
 *   description = @Translation("Places the source image over a background image.")
 * )
 */
class Background extends ImagemagickImageToolkitOperationBase {

  use BackgroundTrait;

  /**
   * {@inheritdoc}
   */
  protected function execute(array $arguments) {
    // Reset any gravity settings from earlier effects.
    $op = '-gravity None';

    // Set transparent background.
    $op .= " -background transparent";

    // Set the dimensions of the background.
    $w = $arguments['background_image']->getToolkit()->getWidth();
    $h = $arguments['background_image']->getToolkit()->getHeight();
    // Reverse offset sign. Offset arguments require a sign in front.
    $x = $arguments['x_offset'] > 0 ? ('-' . $arguments['x_offset']) : ('+' . -$arguments['x_offset']);
    $y = $arguments['y_offset'] > 0 ? ('-' . $arguments['y_offset']) : ('+' . -$arguments['y_offset']);
    $op .= " -extent {$w}x{$h}{$x}{$y} ";

    // Add the background image.
    $op .= $this->getToolkit()->escapeShellArg($arguments['background_image']->getToolkit()->getSourceLocalPath());

    // Compose it with the destination.
    if ($arguments['opacity'] == 100) {
      $op .= ' -compose dst-over -composite';
    }
    else {
      $op .= " -compose blend -define compose:args=100,{$arguments['opacity']} -composite";
    }

    $this->getToolkit()
      ->addArgument($op)
      ->setWidth($w)
      ->setHeight($h);
    return TRUE;
  }

}
